import { useEffect, useState } from "react";
import type { CreateMovie } from "../../types";

interface MovieFormProps {
	defaultValue?: CreateMovie;
	disabled?: boolean;
	onSubmit: (createMovie: CreateMovie) => void;
}

export default function MovieForm({
	defaultValue,
	onSubmit,
	disabled,
}: MovieFormProps) {
	const [form, setForm] = useState<CreateMovie>(
		defaultValue || {
			title: "",
			overview: "",
			release_date: "",
			backdrop_path: "",
			poster_path: "",
			tmdb_id: 0,
		},
	);

	useEffect(() => {
		if (defaultValue) setForm(defaultValue);
	}, [defaultValue]);

	function handleInputChange(
		event: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>,
	) {
		const target = event.target;
		const name = target.name;
		const value = target.value;

		setForm({
			...form,
			[name]: value,
		});
	}

	function handleBtnClick() {
		onSubmit({ ...form });
	}

	return (
		<div className="card">
			<div className="card-body">
				<form>
					<div className="form-floating mb-3">
						<input
							type="text"
							className="form-control"
							id="title"
							name="title"
							value={form.title}
							onChange={handleInputChange}
						/>
						<label className="form-label">Title</label>
					</div>
					<div className="form-floating mb-3">
						<textarea
							className="form-control"
							id="overview"
							name="overview"
							style={{ minHeight: "96px" }}
							onChange={handleInputChange}
							value={form.overview}
						/>
						<label className="form-label">Overview</label>
					</div>
					<div className="form-floating mb-3">
						<input
							type="date"
							className="form-control"
							id="release_date"
							name="release_date"
							onChange={handleInputChange}
							value={form.release_date}
						/>
						<label className="form-label">Release date</label>
					</div>
					<div className="form-floating mb-3">
						<input
							type="text"
							className="form-control"
							id="backdrop_path"
							name="backdrop_path"
							onChange={handleInputChange}
							value={form.backdrop_path}
						/>
						<label className="form-label">Backdrop path</label>
					</div>
					<div className="form-floating mb-3">
						<input
							type="text"
							className="form-control"
							id="poster_path"
							name="poster_path"
							onChange={handleInputChange}
							value={form.poster_path}
						/>
						<label className="form-label">Poster path</label>
					</div>
				</form>
				<div className="d-grid">
					<button
						type="button"
						disabled={disabled}
						onClick={handleBtnClick}
						className="btn btn-primary"
					>
						Create
					</button>
				</div>
			</div>
		</div>
	);
}
