import { useState } from "react";
import type { CreateMovie } from "../../types";
import MovieForm from "./MovieForm";

declare let bootstrap: any;

interface MovieFormDataProps {
	defaultValue?: CreateMovie;
}

export default function MovieFormData({ defaultValue }: MovieFormDataProps) {
	const [loading, setLoading] = useState<boolean>(false);
	const [showModal, setShowModal] = useState<boolean>(false);

	function handleOnSubmit(createMovie: CreateMovie) {
		const searchParams = new URLSearchParams(window.location.search);
		setLoading(true);

		fetch("/api/movies", {
			method: "POST",
			body: JSON.stringify(createMovie),
			credentials: "include",
			headers: {
				Accept: "application/json",
				"Content-Type": "application/json",
			},
		})
			.then((res) => res.json())
			.then((movie) => {
				const myModal = new bootstrap.Modal(
					document.getElementById("exampleModal"),
				);

				myModal?.show();
				console.log(movie);
			})
			.catch((err) => console.log(err))
			.finally(() => setLoading(false));
	}

	return (
		<>
			<MovieForm
				defaultValue={defaultValue}
				disabled={loading}
				onSubmit={handleOnSubmit}
			/>
			<div className="modal fade" id="exampleModal" role="dialog">
				<div className="modal-dialog" role="document">
					<div className="modal-content">
						<div className="modal-header">
							<h5 className="modal-title">Modal title</h5>
							<button
								type="button"
								className="close"
								data-dismiss="modal"
								aria-label="Close"
							>
								<span aria-hidden="true">&times;</span>
							</button>
						</div>
						<div className="modal-body">
							<p>Modal body text goes here.</p>
						</div>
						<div className="modal-footer">
							<button type="button" className="btn btn-primary">
								Save changes
							</button>
							<button
								type="button"
								className="btn btn-secondary"
								data-dismiss="modal"
							>
								Close
							</button>
						</div>
					</div>
				</div>
			</div>
		</>
	);
}
